aboutsummaryrefslogtreecommitdiffstats
path: root/src/uds/uds.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/uds/uds.h')
-rw-r--r--src/uds/uds.h16
1 files changed, 12 insertions, 4 deletions
diff --git a/src/uds/uds.h b/src/uds/uds.h
index cb132330..3389adff 100644
--- a/src/uds/uds.h
+++ b/src/uds/uds.h
@@ -91,15 +91,23 @@ int diagnostic_payload_to_integer(const DiagnosticResponse* response);
/* Public: Render a DiagnosticResponse as a string into the given buffer.
*
- * TODO implement this
+ * response - the response to convert to a string, for debug logging.
+ * destination - the target string buffer.
+ * destination_length - the size of the destination buffer, i.e. the max size
+ * for the rendered string.
+ */
+void diagnostic_response_to_string(const DiagnosticResponse* response,
+ char* destination, size_t destination_length);
+
+/* Public: Render a DiagnosticRequest as a string into the given buffer.
*
* message - the response to convert to a string, for debug logging.
* destination - the target string buffer.
* destination_length - the size of the destination buffer, i.e. the max size
* for the rendered string.
*/
-// void diagnostic_response_to_string(const DiagnosticResponse* response,
- // char* destination, size_t destination_length);
+void diagnostic_request_to_string(const DiagnosticRequest* request,
+ char* destination, size_t destination_length);
/* Public: For many OBD-II PIDs with a numerical result, translate a diagnostic
* response payload into a meaningful number using the standard formulas.
@@ -91,15 +91,23 @@ int diagnostic_payload_to_integer(const DiagnosticResponse* response);
*
- * message - the response to convert to a string, for debug logging.
+ * request - the request to convert to a string, for debug logging.
* destination - the target string buffer.
* destination_length - the size of the destination buffer, i.e. the max size